<TS language="es_MX" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Crear una dirección nueva</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copiar la dirección seleccionada al portapapeles del sistema</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Eliminar la dirección actualmente seleccionada de la lista</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Domicilio</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sin etiqueta)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialogo de contraseña</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Ingrese la contraseña</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nueva contraseña</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Repita la nueva contraseña</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Cartera encriptada.</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Esta operación necesita la contraseña de su cartera para desbloquear su cartera.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Desbloquear cartera.</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Cambiar contraseña</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Ingrese la antugüa y nueva contraseña de la cartera</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirmar la encriptación de cartera</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Cartera encriptada</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>La encriptación de la cartera falló</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>La encriptación de la cartera falló debido a un error interno. Su cartera no fue encriptada.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Las contraseñas dadas no coinciden</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>El desbloqueo de la cartera Fallo</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>La contraseña ingresada para la des encriptación de la cartera es incorrecto</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Cartera</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Vista previa</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Mostrar la vista previa general de la cartera</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Enviar</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Recibir</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Explorar el historial de transacciones</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>S&amp;alir</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Salir de la aplicación</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opciones</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Mostrar / Ocultar</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Encriptar cartera</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Cambiar contraseña...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Cambiar la contraseña usada para la encriptación de la cartera</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Firmar &amp;mensaje</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verificar mensaje...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Depurar ventana</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Abrir consola de depuración y diagnostico</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuraciones</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Actualizado al dia </translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Recibiendo...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Enviar Transacción</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transacción entrante</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>La cartera esta &lt;b&gt;encriptada&lt;/b&gt; y &lt;b&gt;bloqueada&lt;/b&gt; actualmente </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Monto:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Cuota:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Después de los cargos por comisión. </translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Cambio</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Monto</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado </translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Domicilio</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copiar dirección </translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copiar capa </translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>copiar monto</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>copiar cantidad</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>copiar cuota</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>copiar despues de cuota</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>copiar bytes</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>copiar cambio</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sin etiqueta)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Editar dirección</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiqueta</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Dirección</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nueva dirección de entregas</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nueva dirección de entregas</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Editar dirección de entregas</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Editar dirección de envios</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>El domicilio ingresado "%1" ya existe en la libreta de direcciones</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>No se puede desbloquear la cartera</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>La generación de la nueva clave fallo</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Enviar monedas</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Monto:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Cuota:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Después de los cargos por comisión. </translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Enviar a múltiples receptores a la vez</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Confirme la acción de enviar</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>copiar cantidad</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>copiar monto</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>copiar cuota</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>copiar despues de cuota</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>copiar bytes</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>copiar cambio</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Confirme para mandar monedas</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>El monto a pagar debe ser mayor a 0</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sin etiqueta)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>M&amp;onto</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Pagar &amp;a:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mensaje:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiqueta</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pegar dirección  del portapapeles</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Ingrese una etiqueta para esta dirección para agregarlo en su libreta de direcciones.</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pegar dirección  del portapapeles</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Abrir hasta %1</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/No confirmado</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 confirmaciones</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, no ha sido transmitido aun</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconocido</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Monto</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Detalles de la transacción</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Este panel muestras una descripción detallada de la transacción</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Domicilio</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Monto</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Abrir hasta %1</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Confimado (%1 confirmaciones)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generado pero no aprovado</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Recivido con</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Enviar a</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pagar a si mismo</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Fecha y hora en que la transacción fue recibida </translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Escriba una transacción</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Direccion del destinatario de la transacción</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Cantidad removida del saldo o agregada </translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Esta semana </translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Este mes </translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>El mes pasado </translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Este año</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Recivido con</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Enviar a</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Para ti mismo</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minado </translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Otro</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Monto minimo </translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copiar dirección </translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copiar capa </translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>copiar monto</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Editar capa </translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Domicilio</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Monto</translation>
    </message>
    <message>
        <source>to</source>
        <translation>Para</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Usage:</source>
        <translation>Uso:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Lista de comandos</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Cargando direcciones...</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Cargando indice de bloques... </translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Cargando billetera...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Carga completa</translation>
    </message>
    </context>
</TS>